#ifndef MYCODE_CJULIANDATE_H_ 
#define MYCODE_CJULIANDATE_H_ 

#include <string> 
  
/** 
 * Diese Klasse repräsentiert ein Julianisches Datum ohne Uhrzeit. 
 */ 
class CJulianDate { 
private: 
    long m_days; 
  
    /** 
     * Formatiert die übergebene Tagesnummer (1-31) wie folgt: Ist die Zahl 
     * einstellig, wird ein Leerzeichen vorangestellt (3 --> " 3"). Stimmt 
     * die Zahl mit dem Tag des von diesem Objekt repräsentierten 
     * gregorianischen Datums überein, wird das Ergebnis mit eckigen 
     * Klammern umgeben ("10" --> "[10]"), sonst werden am Anfang und 
     * am Ende je ein Leerzeichen ergänzt ("10" --> " 10 "). 
     */ 
    std::string formatDayNumber (short day) const; 
  
public: 
    /** 
     * Erzeugt ein neues Objekt mit dem angegebenen Julianischen Datum. 
     */ 
    CJulianDate(long date = 0); 
  
    /** 
     * Erzeugt ein neues Objekt, dessen Wert aus dem angegebene Gregorianische Datum 
     * berechnet wird. 
     * 
     * - year: das Jahr 
     * - month: der Monat (Januar = 1) 
     * - day: der Tag (erster Tag eines Monats: 1) 
     */ 
    CJulianDate(int year, short month, short day); 
  
    /** 
     * Liefert das Julianische Datum (Tage seit dem 1. Januar -4712 (4713 v. Chr)). 
     */ 
    long getJulianDate() const; 
  
    /** 
     * Übernimmt das angegebene Julianische Datum. 
     */ 
    void setJulianDate(long date); 
  
    /** 
     * Liefert den aktuallen Wert als Gregorianisches Datum. 
     * 
     * - year: das Jahr 
     * - month: der Monat (Januar = 1) 
     * - day: der Tag (erster Tag eines Monats: 1) 
     */ 
    void toGregorianDate(int& year, short& month, short& day) const; 
  
    /** 
     * Konvertiert und übernimmt das angegebene Gregorianische Datum. 
     * 
     * - year: das Jahr 
     * - month: der Monat (Januar = 1) 
     * - day: der Tag (erster Tag eines Monats: 1) 
     */ 
    void fromGregorianDate(int year, short month, short day); 
  
    /** 
     * Liefert den Wochentag zu dem aktuellen Datum (Montag = 1). 
     */ 
    int dayOfWeek() const; 
  
    /** 
     * Liefert den Namen des Wochentags zu dem aktuellen Datum (Montag = 1). 
     */ 
    std::string dayOfWeekAsName() const; 
  
    /** 
     * Addiert die angegebene Anzahl Tage zu diesem Julianischen Datum hinzu. 
     */ 
    CJulianDate& operator+= (long days) { 
        m_days += days; 
        return *this; 
    } 
  
    /** 
     * Vergleicht zwei Julianische Daten und liefert true, wenn das als 
     * linker Operand angegebene Datum vor dem als rechter Operand 
     * angegebenen liegt. 
     */ 
    bool operator< (const CJulianDate& rhs) const; 

	void prettyPrintMonth();
  
}; 

std::ostream& operator << (std::ostream& lop, const CJulianDate& rhs);

#endif /* MYCODE_CJULIANDATE_H_ */

